#
# spec file for package ghc-zip-archive
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name zip-archive
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.1.1
Release:        lp150.1.8
Summary:        Library for creating and modifying zip archives
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-digest-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-old-time-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
The zip-archive library provides functions for creating, modifying, and
extracting files from zip archives.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.markdown changelog

%changelog
* Sun Jun 25 2017 psimons@suse.com
- Update to version 0.3.1.1.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 0.3.1.
* Wed May  3 2017 psimons@suse.com
- Update to version 0.3.0.6 with cabal2obs.
* Mon Jan 23 2017 psimons@suse.com
- Update to version 0.3.0.5 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.3.0.5 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.3.7 revision 0 with cabal2obs.
* Sun Feb  1 2015 mpluskal@suse.com
- Update to 0.2.3.7:
  * Declared test suite's dependency on 'zip' using custom Setup.lhs (#21,#22).
  * Removed hard-coded path to zip in test suite (#21).
  * Removed misplaced build-depends in cabal file.
  * Allow compilation with binary >= 0.5.  Note that toArchiveOrFail
    is not safe when compiled against binary < 0.7; it will never
    return a Left value, and will raise an error if parsing fails,
    just like toArchive.  This is documented in the haddocks.
    This is ugly, but justified by the need to have a version
    of zip-archive that compiles against older versions of binary.
  * Make sure all path comparisons compare normalized paths.
    So, findEntryByPath "foo" will find something stored as "./foo"
    in the zip container.
  * Better normalization of file paths:  "./foo/bar" and "foo/./bar"
    are now treated the same, for example.  Note that we do not
    yet treat "foo/../bar" and "bar" as the same.
  * Removed lower bound on directory (>= 1.2), which caused build
    failures with GHC 7.4 and 7.6.
  * Added travis script for automatic testing on 3 GHC versions.
  * Require binary >= 0.7 and directory >= 1.2.  The newer binary
    is needed to provide toArchiveOrFail.  The other change is
    mainly for convenience, to avoid lots of ugly conditional
    compilation.
  * Export new function `toArchiveOrFail`.  Closes #17.
  * Set general purpose bit flag to use UTF8 in local file header.
    Otherwise we get a mismatch between the flag in the central
    directory and the flag in the local file header, which causes some
    programs not to be able to extract the files.  Closes #19.
  * Fix a stack overflow in getWordsTillSig (Tristan Ravitch).
    recognize UTF-8 encoded file names (Tobias Brandt).
  * Added OptLocation, to specify the path to which a file
    is to be added when readEntry is used (Stephen McIntosh).
* Thu Mar 13 2014 sbahling@suse.com
- Add missing %%defattr
* Tue Dec 31 2013 peter.trommler@ohm-hochschule.de
- update to 0.2 from upstream
  * replace dependency on utf8-string by text
* Wed May 15 2013 peter.trommler@ohm-hochschule.de
- new spec file template generated by cabal-rpm
* Mon Mar 11 2013 peter.trommler@ohm-hochschule.de
- update to 0.1.3.4 from upstream
  * use new binary API
  * use new directory API
  * general code cleanup
  * added testsuite
- requirement for pandoc 1.11
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.1.1.8 from upstream
  * fix parsing of "version needed to extract" field
  * license now BSD-3-Clause
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 spec file template
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
